﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.OpenAccess;
using Telerik.OpenAccess.Metadata;

namespace TwoModelsDemo
{
    public class MergedContext : OpenAccessContext
    {
        private static string connectionStringName = @"AdventureWorksConnection";

        private static BackendConfiguration backend = GetBackendConfiguration();
        private static MetadataSource metadataSource = GetMetadataSource();

        public MergedContext()
            : base(connectionStringName, backend, metadataSource)
        { }

        public MergedContext(string connection)
            : base(connection, backend, metadataSource)
        { }

        public MergedContext(BackendConfiguration backendConfiguration)
            : base(connectionStringName, backendConfiguration, metadataSource)
        { }

        public MergedContext(string connection, MetadataSource metadataSource)
            : base(connection, backend, metadataSource)
        { }

        public MergedContext(string connection, BackendConfiguration backendConfiguration, MetadataSource metadataSource)
            : base(connection, backendConfiguration, metadataSource)
        { }

        public IQueryable<ProductCategory> ProductCategories
        {
            get
            {
                return this.GetAll<ProductCategory>();
            }
        }

        public IQueryable<Product> Products
        {
            get
            {
                return this.GetAll<Product>();
            }
        }

        public static BackendConfiguration GetBackendConfiguration()
        {
            BackendConfiguration backend = new BackendConfiguration();
            backend.Backend = "mssql";
            return backend;
        }

        private static MetadataSource GetMetadataSource()
        {
            XmlMetadataSource source1 = XmlMetadataSource.FromAssemblyResource("EntityDiagrams.rlinq");
            XmlMetadataSource source2 = XmlMetadataSource.FromAssemblyResource("EntityDiagrams2.rlinq");

            return new AggregateMetadataSource(source1, source2);
        }
    }
}
